@@ -16,7 +16,7 @@ impl<T> Inverse<T> for Matrix<T> where T: Field + Scalar
     /// let a: Matrix<f64> = Matrix::new(2, 2, vec![1.0, 0.0, 3.0, -7.0]);
     /// let b_inv: Matrix<f64> = a.inv().unwrap();
     /// ```
-    fn inv(self: &Self) -> Result<Matrix<T>, ()>
+    fn inv(&self) -> Result<Matrix<T>, ()>
     {
         self.inv_r()
     }
@@ -24,7 +24,7 @@ impl<T> Inverse<T> for Matrix<T> where T: Field + Scalar
 
 impl<T> Matrix<T> where T: Field + Scalar
 {
-    pub fn inv_r(self: &Self) -> Result<Matrix<T>, ()>
+    pub fn inv_r(&self) -> Result<Matrix<T>, ()>
     {
         let (m, n): (usize, usize) = self.dim();
         let m_i32: i32 = m as i32;
