@@ -29,7 +29,7 @@ impl<T> Sub for Matrix<T>
     ///
     /// let c: Matrix<f64> = a - b;
     /// ```
-    fn sub(self: Self, rhs: Self) -> Self::Output
+    fn sub(self, rhs: Self) -> Self::Output
     {
         (&self).sub(&rhs)
     }
@@ -40,7 +40,7 @@ impl<'a, 'b, T> Sub<&'b Matrix<T>> for &'a Matrix<T>
 {
     type Output = Matrix<T>;
 
-    fn sub(self: Self, rhs: &'b Matrix<T>) -> Self::Output
+    fn sub(self, rhs: &'b Matrix<T>) -> Self::Output
     {
         assert_eq!(self.dim(), rhs.dim());
         let (m, n) = rhs.dim();
@@ -59,7 +59,7 @@ impl<'a, 'b, T> Sub<&'b Matrix<T>> for &'a mut Matrix<T>
 {
     type Output = &'a mut Matrix<T>;
 
-    fn sub(self: Self, rhs: &'b Matrix<T>) -> Self::Output
+    fn sub(self, rhs: &'b Matrix<T>) -> Self::Output
     {
         assert_eq!(self.dim(), rhs.dim());
         self.data.iter_mut().zip(rhs.data.iter()).for_each(|(x, y)| *x -= *y);
@@ -84,7 +84,7 @@ impl<'a, 'b, T> Sub<&'b T> for &'a Matrix<T>
     /// let a: Matrix<f64> = Matrix::new(2, 2, vec![1.0, 0.0, 3.0, -7.0]);
     /// let b: Matrix<f64> = &a - &-4.0;
     /// ```
-    fn sub(self: Self, rhs: &T) -> Self::Output
+    fn sub(self, rhs: &T) -> Self::Output
     {
         self.apply(&|x: &T| -> T { *x - *rhs })
     }
@@ -107,7 +107,7 @@ impl<'a, 'b, T> Sub<&'b T> for &'a mut Matrix<T>
     /// let a: Matrix<f64> = Matrix::new(2, 2, vec![1.0, 0.0, 3.0, -7.0]);
     /// let b: Matrix<f64> = &a - &-4.0;
     /// ```
-    fn sub(self: Self, rhs: &T) -> Self::Output
+    fn sub(self, rhs: &T) -> Self::Output
     {
         let _ = self.data.iter_mut().for_each(&|x: &mut T| *x -= *rhs);
         self
@@ -129,7 +129,7 @@ impl<T> Sub<T> for Matrix<T>
     /// let a: Matrix<f64> = Matrix::new(2, 2, vec![1.0, 0.0, 3.0, -7.0]);
     /// let b: Matrix<f64> = a - -4.0;
     /// ```
-    fn sub(self: Self, rhs: T) -> Self::Output
+    fn sub(self, rhs: T) -> Self::Output
     {
         (&self).sub(&rhs)
     }
