@@ -23,22 +23,22 @@ use std::clone::Clone;
 ///  f(x) \to min
 /// ```
 ///
-/// input: $` f \colon \mathbb{R}^{n} \to \mathbb{R} `$ with initial
-/// approximation $` x_{0} \in \mathbb{R}^{n} `$
+/// input: $ f \colon \mathbb{R}^{n} \to \mathbb{R} $ with initial
+/// approximation $ x_{0} \in \mathbb{R}^{n} $
 ///
-/// output: $` x_{k} `$
+/// output: $ x_{k} $
 ///
-/// 1. Initialization: Choose $` \sigma \in (0, 1) `$
+/// 1. Initialization: Choose $ \sigma \in (0, 1) $
 ///
-///     $` \rho > 0, k := 0 `$
-/// 2. Solve de equation system $` \nabla^{2} f(x_{k})d_{k} = -\nabla f(x_{k})
-/// `$ 3. If the euqation is not solvable, or the condition
-/// $` \nabla f(x_{k})^{T}d_{k} \leq -\rho \lvert \lvert \nabla f(x_k) \rvert
-/// \rvert_{2}^{2} `$  is not fullfilled Than $` d_{k} := \nabla f(x_{k}) `$
-/// 4. $` \alpha_{k} := 1 `$
-/// 5. while  $` f(x_{k} + \alpha_{k}d_{k}) > f(x_{k}) + \sigma \alpha_{k}
-/// \nabla f(x_{k})^{T}d_{k} `$ set $` \alpha_{k} `$ 6. $` x_{k + 1} := x_{k} +
-/// d_{k} `$ 7. $` k := k + 1 `$  go to 2.
+///     $ \rho > 0, k := 0 $
+/// 2. Solve de equation system $ \nabla^{2} f(x_{k})d_{k} = -\nabla f(x_{k})
+/// $ 3. If the euqation is not solvable, or the condition
+/// $ \nabla f(x_{k})^{T}d_{k} \leq -\rho \lvert \lvert \nabla f(x_k) \rvert
+/// \rvert_{2}^{2} $  is not fullfilled Than $ d_{k} := \nabla f(x_{k}) $
+/// 4. $ \alpha_{k} := 1 $
+/// 5. while  $ f(x_{k} + \alpha_{k}d_{k}) > f(x_{k}) + \sigma \alpha_{k}
+/// \nabla f(x_{k})^{T}d_{k} $ set $ \alpha_{k} $ 6. $ x_{k + 1} := x_{k} +
+/// d_{k} $ 7. $ k := k + 1 $  go to 2.
 ///
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[derive(Clone, Copy, Debug)]
@@ -74,7 +74,7 @@ impl<T> Newton<T> where T: Real
     /// # Return
     ///
     /// local minimum
-    pub fn minimize<F>(self: &Self, func: &F, x_0: &Vector<T>) -> OptimResult<Vector<T>>
+    pub fn minimize<F>(&self, func: &F, x_0: &Vector<T>) -> OptimResult<Vector<T>>
         where F: Optim<T>
     {
         let mut x_n: Vector<T> = x_0.clone();
